Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| PGL DISTRIBUICAO DE ALIMENTOS LTDA
CNPJ: 87.397.865/0021-65 Inscrição Estadual: 1090357122
Evandro Behr - RS 509 KM 08, 6645, CAMOBI, Santa Maria, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 98478 Série: 205 Data de Emissão: 05/11/2019 19:45:55
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 1187 3978 6500 2165 6520 5000 0984 7810 0398 9673
Protocolo de Autorização: 143191524695249
CONSUMIDOR
Consumidor não identificado
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
10067230 | M TOMATE FUGINI TRAD ZERO SC 340G | 4 | UN | 1,99 | 7,96
546150 | MILHO QUERO SC 200G | 1 | UN | 2,19 | 2,19
Valor total R$ | 10,15
Valor descontos R$ | 0,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:35